"""Basic utilities for cloudpath."""


import os
import pathlib


def cache_dir() -> pathlib.Path:
    """Find cache directory for cloudpath.

    Return:
        cache directory path
    """

    try:
        cache_dir = pathlib.Path(os.environ["CLOUDPATH_CACHE_DIR"])
    except KeyError:
        cache_dir = pathlib.Path.home() / ".cloudpath"

    cache_dir.mkdir(mode=755, parents=True, exist_ok=True)
    return cache_dir


def file_basename(path: str) -> bool:
    """Check if path is a valid basename for a Unix file path.

    Args:
        path: path to check

    Return:
        whether path is a valid basename
    """

    return "/" not in path
