import importlib
import pathlib
from types import ModuleType
from typing import ClassVar, Union


class GSPath:
    """GCP cloud storage path manager."""

    _gcs: ClassVar[ModuleType]

    def __init__(self, path_: Union[str, pathlib.Path]):
        """Create a new PathGCS instance."""

        self._load_gcs()
        self._path = str(path_)

    @classmethod
    def _load_gcs(cls) -> None:
        """Import the google.cloud.storage module for handling GCP cloud storage paths.

        Dynamically imported so that users can use just PathFS without installing
        google-cloud-storage.
        """

        if not hasattr(cls, "_gcs"):
            cls._gcs = importlib.import_module("google.cloud.storage")
